@@ -8,7 +8,7 @@ class Command(SyncDBCommand):
     """
     
     def handle_noargs(self, **options):
-        if options.get('interactive'):
+        if options.get("interactive"):
             confirm = raw_input("""
 You have requested a database sync.
 This CONFLICTS WITH NASHVEGAS.
@@ -16,9 +16,9 @@ Are you sure you want to do this?
 
 Type 'yes' to continue, or 'no' to cancel: """)
         else:
-            confirm = 'yes'
+            confirm = "yes"
         
-        if confirm == 'yes':
+        if confirm == "yes":
             super(Command, self).handle_noargs(**options)
         else:
             print "Sync cancelled."
